OC.L10N.register(
    "mail",
    {
    "Creating account failed: " : "একাউন্ট তৈরী করা গেলনা:",
    "Mail" : "মেইল",
    "Name" : "নাম",
    "Password" : "কূটশব্দ",
    "None" : "কোনটিই নয়",
    "Save" : "সংরক্ষণ",
    "Connect" : "সংযুক্ত হও",
    "Sending …" : "পাঠানো হচ্ছে......",
    "Go back" : "ফিরে যাও",
    "Send" : "পাঠাও",
    "Choose a file to add as attachment" : "সংযুক্তি দেয়ার জন্য একটি ফাইল নির্বাচন করুন",
    "Select" : "সিলেক্ট",
    "Move" : "Move",
    "Delete" : "মুছে",
    "Choose" : "বেছে নিন",
    "Important" : "গুরুত্বপূর্ণ",
    "Favorites" : "প্রিয়জন",
    "Other" : "অন্যান্য",
    "Choose a folder to store the attachment in" : "সংযুক্তি সংরক্ষনের জন্য একটি ফোল্ডার নির্বাচন করুন",
    "Settings" : "সেটিংস",
    "Quota" : "কোটা",
    "Add folder" : "Add folder",
    "Cancel" : "বাতির",
    "Mark all as read" : "সব পঠিত হিসেবে চিহ্নিত কর",
    "Clear cache" : "ক্যাশে পরিষ্কার কর",
    "Delete folder" : "ফোল্ডার মোছ",
    "Reply" : "জবাব",
    "General" : "সাধারণ",
    "User" : "User",
    "Host" : "হোস্ট",
    "Port" : "পোর্ট",
    "Keyboard shortcuts" : "কী-বোর্ড শর্টকাট",
    "Search" : "Search",
    "Refresh" : "নবোদ্যম",
    "All" : "সবাই"
},
"nplurals=2; plural=(n != 1);");
